@@ -128,11 +128,11 @@ I<StreamFinder.pl> and run it from the command line with a supported streaming
 site URL as the argument.  You can then edit it to tailor it to your needs.
 
 The currently-supported websites are:  podcasts.apple.com (L<StreamFinder::Apple>), 
-bitchute.com (L<StreamFinder::Bitchute>, blogger.com (L<StreamFinder::Blogger>), 
+bitchute.com (L<StreamFinder::Bitchute>), blogger.com (L<StreamFinder::Blogger>), 
 brighteon.com (L<StreamFinder::Brighteon>), castbox.fm (L<StreamFinder::Castbox>), 
 podcasts.google.com (L<StreamFinder::Google>), 
 iheartradio.com (L<StreamFinder::IHeartRadio>), 
-radio.net (L<StreamFinder::RadioNet>), 
+odysee.com (L<StreamFinder::Odysee>), radio.net (L<StreamFinder::RadioNet>), 
 rumble.com (L<StreamFinder::Rumble>),
 sermonaudio.com (L<StreamFinder::SermonAudio>), 
 spreaker.com podcasts (L<StreamFinder::Spreaker>), 
@@ -327,7 +327,7 @@ the "icon image" data, if any, will be returned.
 
 Returns the station / podcast / video's type (I<submodule-name>).  
 (one of:  "Anystream", "Apple", "BitChute", "Blogger", "Brighteon", 
-"Castbox", "Google", "IHeartRadio", "RadioNet", "Rumble", 
+"Castbox", "Google", "IHeartRadio", "Odysee", "RadioNet", "Rumble", 
 "SermonAudio", "Spreaker", "Tunein", "Youtube" or "Vimeo" - 
 depending on the sight that matched the URL).
 
@@ -384,7 +384,7 @@ L<URI::Escape>, L<HTML::Entities>, L<LWP::UserAgent>
 
 =head1 RECCOMENDS
 
-youtube-dl (for Youtube, Brighteon, Tunein, Vimeo)
+youtube-dl (for Youtube, Brighteon, Odysee, Tunein, Vimeo)
 
 wget
 
@@ -472,7 +472,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.61';
+our $VERSION = '1.62';
 our $DEBUG = 0;
 
 require Exporter;
@@ -480,7 +480,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw();
 my @supported_mods = (qw(Anystream Apple Bitchute Blogger Brighteon Castbox Google IHeartRadio
-		RadioNet Rumble SermonAudio Spreaker Tunein Vimeo Youtube));
+		Odysee RadioNet Rumble SermonAudio Spreaker Tunein Vimeo Youtube));
 
 my %haveit;
 
@@ -540,6 +540,8 @@ sub new
 		return new StreamFinder::Google($url, @args);
 	} elsif ($haveit{'SermonAudio'} && $url =~ m#\bsermonaudio\.com\/#) {
 		return new StreamFinder::SermonAudio($url, @args);
+	} elsif ($haveit{'Odysee'} && $url =~ m#\bodysee\.com\/#) {
+		return new StreamFinder::Odysee($url, @args);
 	} elsif ($haveit{'Youtube'}) {  #DEFAULT TO youtube-dl SINCE SO MANY URLS ARE HANDLED THERE NOW.
 		my $yt = new StreamFinder::Youtube($url, @args);
 		return $yt  if (defined($yt) && $yt && $yt->count() > 0);
