@@ -526,7 +526,7 @@ sub getIconURL
 
 	unless ($self->{'articonurl'}) {
 		my $html = '';
-		return ''  unless ($self->{'albumartist'});
+		return ''  unless ($self->{'albumartist'} && $self->{'albumartist'} =~ m#^https?\:\/\/#);
 
 		my $url2fetch = $self->{'albumartist'};
 		print STDERR "-0(Fetch Apple Channel for alt. icon from $url2fetch): \n"  if ($DEBUG);
@@ -547,7 +547,7 @@ sub getIconURL
 		}
 
 		print STDERR "-1: html=$html=\n"  if ($DEBUG > 1);
-		return undef  unless ($html);
+		return ''  unless ($html);
 
 		my ($pre, $post) = split(/\"included\"\:/, $html, 2);
 		$html = '';
