@@ -96,7 +96,9 @@ sub new
 	$self->{'year'} = '';
 	$self->{'genre'} = '';
 	$self->{'iconurl'} = '';
+	$self->{'imageurl'} = '';
 	$self->{'articonurl'} = '';
+	$self->{'artimageurl'} = '';
 	$self->{'streams'} = [];
 	$self->{'cnt'} = 0;
 	$self->{'total'} = 0;
@@ -255,19 +257,25 @@ sub getIconData
 sub getImageURL
 {
 	my $self = shift;
-	return $self->{'imageurl'};  #URL TO THE STATION'S BANNER IMAGE, IF ANY.
+	return $self->{'imageurl'};  #URL TO THE STATION'S|CHANNEL'S BANNER IMAGE, IF ANY.
+	return (defined($_[0]) && $_[0] =~ /^\-?artist/i)
+			? $self->{'artimageurl'} : $self->{'imageurl'};  #URL TO THE STATION'S|CHANNEL'S BANNER IMAGE, IF ANY.
 }
 
 sub getImageData
 {
 	my $self = shift;
-	return ()  unless ($self->{'imageurl'});
+
+	my $whichurl = (defined($_[0]) && $_[0] =~ /^\-?artist/i)
+			? 'artimageurl' : 'imageurl';
+	return ()  unless ($self->{$whichurl});
+
 	my $ua = LWP::UserAgent->new(@{$self->{'_userAgentOps'}});		
 	$ua->timeout($self->{'timeout'});
 	$ua->cookie_jar({});
 	$ua->env_proxy;
 	my $art_image = '';
-	my $response = $ua->get($self->{'imageurl'});
+	my $response = $ua->get($self->{$whichurl});
 	if ($response->is_success) {
 		$art_image = $response->decoded_content;
 	} else {
@@ -275,13 +283,13 @@ sub getImageData
 		my $no_wget = system('wget','-V');
 		unless ($no_wget) {
 			print STDERR "\n..trying wget...\n"  if ($DEBUG);
-			my $iconUrl = $self->{'iconurl'};
+			my $iconUrl = $self->{$whichurl};
 			$art_image = `wget -t 2 -T 20 -O- -o /dev/null \"$iconUrl\" 2>/dev/null `;
 		}
 	}
 	return ()  unless ($art_image);
-	my $image_ext = $self->{'imageurl'};
-	$image_ext = ($self->{'imageurl'} =~ /\.(\w+)$/) ? $1 : 'png';
+	my $image_ext = $self->{$whichurl};
+	$image_ext = ($self->{$whichurl} =~ /\.(\w+)$/) ? $1 : 'png';
 	$image_ext =~ s/[^A-Za-z].*$//;
 	return ($image_ext, $art_image);
 }
